library(vip)
library(reshape2)
library(ggplot2)
library(zoo)


rm(list=ls())

#### Minimal dataset ####

#load the data
df <- read.csv("data.csv",sep=',')
# categorical variables to factors
df[,-c(4:6)] <- lapply(df[,-c(4:6)], factor)

#### Model ####

#select the trainning dataset, 3rd and 4th semester of 2020
data_train <- df[df$year==2020 & df$trim != 1 & df$trim != 2  ,]
#run the model
minimal <- lm(teleworking~ region:sex + employment +log(mobility) , data= data_train)
# summary statistics
summary(minimal)
# run predictions
df$teleworking_prediction <- predict(minimal,df)

#### Plot variable importance ####
o <- vip(minimal, method = "firm")
plot(o)


#### Plot prediction by region ####

df$teleworking_prediction <- df$teleworking_prediction*100
df$teleworking <- df$teleworking*100
df$yearqtr <- as.yearqtr(paste(df$year,df$trim, sep='-'))

for (region in unique(df$region)) {
  new2<- df[df$reg == region,]
  tele_prediction <- aggregate(teleworking_prediction ~ sex +yearqtr, data = new2, FUN= mean  )
  tele<- aggregate(teleworking ~ sex +yearqtr, data = new2, FUN= mean  )
  new3 <- merge(tele_prediction,tele, by =c('sex','yearqtr'), all = TRUE)
  g1 <- ggplot() +geom_line(data = new3[new3$yearqtr != "2020 Q1" & new3$yearqtr != "2020 Q2" ,], aes(x=yearqtr, y=teleworking_prediction, group=sex, color =sex),linetype="dotted")+
    geom_line(data = new3, aes(x=yearqtr, y=teleworking, group=sex, color =sex)) +
    labs(x= "Year-Quarter", y ="Teleworking %", colour= 'Sex') +ylim(0,32) +ggtitle(region)
  #plot Figures
  plot(g1)
  
}


